@@ -2,13 +2,13 @@
 
 package Validation::Class;
 {
-  $Validation::Class::VERSION = '7.04';
+  $Validation::Class::VERSION = '7.11';
 }
 
 use strict;
 use warnings;
 
-our $VERSION = '7.04'; # VERSION
+our $VERSION = '7.11'; # VERSION
 
 use Module::Find;
 use Carp 'confess';
@@ -271,6 +271,10 @@ sub field {
     
     return undef unless ($name && $data);
     
+    confess "Error creating field $name, name is using unconventional naming"
+        unless $name =~ /^[a-zA-Z_](([\w\.]+)?\w)$/
+        xor    $name =~ /^[a-zA-Z_](([\w\.]+)?\w)\:\d+$/;
+    
     return configure_class_proto sub {
         
         my ($proto) = @_;
@@ -297,35 +301,17 @@ sub field {
             
             my ($self, $data) = @_;
             
-            my $proto      = $self->proto;
-            my $fields     = $proto->fields;
-            my $parameters = $proto->unflatten_params;
-            
+            my $proto  = $self->proto;
+            my $fields = $proto->fields;
             my $result = undef;
             
-            if (defined $data && not defined $fields->{$name}->{readonly}) {
+            if (defined $data) {
                 
-                $parameters->{$name} = $data ;
-                
-                # OMG - this is sooo gross !!!
-                # are you really telling me that this is the best you can do
-                
-                # this method-of-operation is like soo computationally expensive
-                # due to the fact that each accessor call serializes/de-serializes
-                # the params hash
-                
-                # fix your work loser
-                
-                # --me
-                
-                $proto->{params} =
-                    Validation::Class::Params->new($parameters);
+                $proto->set_params($name => $data);
                 
             }
             
-            $result = $proto->field_default_value($name, $parameters);
-                
-            $proto->flatten_params($parameters);
+            $result = $proto->get_value($name);
             
             return $result;
             
@@ -666,10 +652,19 @@ sub new {
     
     my %ARGS = @_ ? @_ > 1 ? @_ : "HASH" eq ref $_[0] ? %{$_[0]} : () : ();
     
-    # process collection assignments
+    # bless special collections
     
-    $proto->{fields} = delete $ARGS{fields} if defined $ARGS{fields};
-    $proto->{params} = delete $ARGS{params} if defined $ARGS{params};
+    $proto->{errors} = Validation::Class::Errors->new;
+    $proto->{params} = Validation::Class::Params->new;
+    $proto->{fields} = Validation::Class::Fields->new($proto->{fields}); #!!!
+    
+    # process overridable attributes
+    
+    my $fields = delete $ARGS{fields} if defined $ARGS{fields};
+    my $params = delete $ARGS{params} if defined $ARGS{params};
+    
+    $proto->set_fields($fields) if $fields;
+    $proto->set_params($params) if $params;
     
     # process attribute assignments
     
@@ -679,12 +674,6 @@ sub new {
         
     }
     
-    # bless specific collections
-    
-    $proto->{fields} = Validation::Class::Fields->new(%{$proto->{fields}});
-    
-    $proto->{params} = Validation::Class::Params->new(%{$proto->{params}});
-    
     # process plugins
     
     foreach my $plugin (keys %{$config->{PLUGINS}}) {
@@ -754,7 +743,7 @@ Validation::Class - Self-Validating Object System and Data Validation Framework
 
 =head1 VERSION
 
-version 7.04
+version 7.11
 
 =head1 SYNOPSIS
 
@@ -1011,9 +1000,9 @@ underscore.
     
     $self->login($new_value); # arrayrefs and hashrefs will be flattened
     
-    $self->preference_send_reminders($value);
+    $self->preference_send_reminders;
     
-    $self->preference_send_reminders_text_0($value);
+    $self->preference_send_reminders_text_0;
 
 Protip: Field directives are used to validate scalar and array data. Don't use
 fields to store and validate blessed objects. Please see the *has* keyword
